import { useState } from 'react';
import { Link } from 'react-router-dom';
import { Button } from '@/components/ui/button';
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import { Avatar, AvatarFallback, AvatarImage } from '@/components/ui/avatar';

const authors = [
  {
    id: 1,
    name: 'Alex Johnson',
    skills: ['Photography', 'Graphic Design', 'Video Editing'],
    featured: ['Advanced Photography Course', 'Portrait Composition Guide'],
    bio: 'Professional photographer with 8 years of experience in portrait and landscape photography.',
  },
  {
    id: 2,
    name: 'Maya Patel',
    skills: ['Web Development', 'UI/UX Design', 'JavaScript'],
    featured: ['React Fundamentals', 'Responsive Design Workshop'],
    bio: 'Full-stack developer specializing in modern web technologies and user experience design.',
  },
  {
    id: 3,
    name: 'Carlos Rodriguez',
    skills: ['Music Production', 'Piano', 'Sound Engineering'],
    featured: ['Music Theory Basics', 'Home Studio Setup Guide'],
    bio: 'Music producer and pianist with a passion for teaching audio production techniques.',
  },
  {
    id: 4,
    name: 'Sarah Kim',
    skills: ['Digital Marketing', 'SEO', 'Content Creation'],
    featured: ['Social Media Strategy', 'SEO Optimization Tips'],
    bio: 'Digital marketing specialist helping creators and small businesses grow their online presence.',
  },
  {
    id: 5,
    name: 'David Chen',
    skills: ['Data Science', 'Python', 'Machine Learning'],
    featured: ['Intro to Data Analysis', 'Python for Beginners'],
    bio: 'Data scientist with experience in building predictive models and data visualization.',
  },
];

const SkillFilter = ({ skills, selectedSkills, onSkillToggle }) => {
  const allSkills = [...new Set(skills.flat())];

  return (
    <div className='mb-6'>
      <h3 className='text-lg font-medium mb-4 mt-8'>Filter by Skills</h3>
      <div className='flex flex-wrap gap-2'>
        {allSkills.map((skill) => (
          <Badge
            key={skill}
            variant={selectedSkills.includes(skill) ? 'default' : 'outline'}
            className='cursor-pointer'
            onClick={() => onSkillToggle(skill)}
          >
            {skill}
          </Badge>
        ))}
      </div>
    </div>
  );
};

export default function Authors() {
  const [selectedSkills, setSelectedSkills] = useState([]);

  const handleSkillToggle = (skill) => {
    setSelectedSkills((prev) =>
      prev.includes(skill) ? prev.filter((s) => s !== skill) : [...prev, skill]
    );
  };

  const filteredAuthors =
    selectedSkills.length > 0
      ? authors.filter((author) =>
          author.skills.some((skill) => selectedSkills.includes(skill))
        )
      : authors;

  return (
    <div className='container mx-auto py-8 px-4 md:py-16 lg:py-24'>
      <h1 className='text-3xl font-bold mb-2'>Discover Skilled Authors</h1>
      <p className='text-gray-600 mb-6'>
        Connect with experts and learn new skills through direct collaboration
      </p>

      <SkillFilter
        skills={authors.map((author) => author.skills)}
        selectedSkills={selectedSkills}
        onSkillToggle={handleSkillToggle}
      />

      <div className='grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6 mt-10'>
        {filteredAuthors.map((author) => (
          <Card key={author.id} className='h-full flex flex-col'>
            <CardHeader>
              <div className='flex items-center gap-4'>
                <Avatar>
                  <AvatarImage src={author.avatar} alt={author.name} />
                  <AvatarFallback>
                    {author.name
                      .split(' ')
                      .map((n) => n[0])
                      .join('')}
                  </AvatarFallback>
                </Avatar>
                <div>
                  <CardTitle>{author.name}</CardTitle>
                  <CardDescription className='line-clamp-2 mt-2'>
                    {author.bio}
                  </CardDescription>
                </div>
              </div>
            </CardHeader>
            <CardContent className='flex-grow'>
              <div className='mb-4'>
                <h3 className='text-sm font-medium text-gray-500 mb-2'>
                  Skills
                </h3>
                <div className='flex flex-wrap gap-1.5'>
                  {author.skills.map((skill) => (
                    <Badge key={skill} variant='secondary' className='text-xs'>
                      {skill}
                    </Badge>
                  ))}
                </div>
              </div>
              <div>
                <h3 className='text-sm font-medium text-gray-500 mb-2'>
                  Featured Content
                </h3>
                <ul className='space-y-1 text-sm'>
                  {author.featured.map((item) => (
                    <li key={item} className='flex items-center'>
                      <span className='w-1.5 h-1.5 bg-primary rounded-full mr-2'></span>
                      {item}
                    </li>
                  ))}
                </ul>
              </div>
            </CardContent>
            <CardFooter>
              <Link to={`/messages/${author.id}`} className='w-full'>
                <Button className='w-full'>Connect</Button>
              </Link>
            </CardFooter>
          </Card>
        ))}
      </div>
    </div>
  );
}
