import { useState, useEffect, useRef } from 'react';
import { useParams, Link } from 'react-router-dom';
import { Button } from '@/components/ui/button';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { Avatar, AvatarFallback, AvatarImage } from '@/components/ui/avatar';
import { Input } from '@/components/ui/input';
import { ArrowLeft, Send } from 'lucide-react';

// Sample data for authors
const authors = [
  {
    id: 1,
    name: 'Alex Johnson',
    skills: ['Photography', 'Graphic Design', 'Video Editing'],
  },
  {
    id: 2,
    name: 'Maya Patel',
    skills: ['Web Development', 'UI/UX Design', 'JavaScript'],
  },
  {
    id: 3,
    name: 'Carlos Rodriguez',
    skills: ['Music Production', 'Piano', 'Sound Engineering'],
  },
  {
    id: 4,
    name: 'Sarah Kim',
    skills: ['Digital Marketing', 'SEO', 'Content Creation'],
  },
  {
    id: 5,
    name: 'David Chen',
    skills: ['Data Science', 'Python', 'Machine Learning'],
  },
];

// Sample initial messages for each author
const initialMessages = {
  1: [
    {
      id: 1,
      sender: 'author',
      text: 'Hi there! Interested in learning photography?',
      timestamp: '2025-06-10T14:30:00',
    },
    {
      id: 2,
      sender: 'user',
      text: "Yes! I'd love to improve my portrait photography skills.",
      timestamp: '2025-06-10T14:32:00',
    },
    {
      id: 3,
      sender: 'author',
      text: 'Great! I specialize in portrait photography. What specific aspects are you looking to improve?',
      timestamp: '2025-06-10T14:35:00',
    },
  ],
  2: [
    {
      id: 1,
      sender: 'author',
      text: 'Hello! Looking to learn web development?',
      timestamp: '2025-06-11T10:15:00',
    },
    {
      id: 2,
      sender: 'user',
      text: "Hi Maya! Yes, I'm particularly interested in React.",
      timestamp: '2025-06-11T10:18:00',
    },
    {
      id: 3,
      sender: 'author',
      text: 'Perfect! React is my specialty. Are you a complete beginner or do you have some experience?',
      timestamp: '2025-06-11T10:20:00',
    },
  ],
  3: [
    {
      id: 1,
      sender: 'author',
      text: 'Hola! Want to learn music production?',
      timestamp: '2025-06-12T16:45:00',
    },
    {
      id: 2,
      sender: 'user',
      text: 'Hi Carlos! Yes, I play guitar but want to learn how to record and mix my own songs.',
      timestamp: '2025-06-12T16:48:00',
    },
    {
      id: 3,
      sender: 'author',
      text: "That's awesome! Home recording is a great skill for guitarists. What DAW are you using?",
      timestamp: '2025-06-12T16:50:00',
    },
  ],
  4: [
    {
      id: 1,
      sender: 'author',
      text: 'Hi there! Need help with digital marketing?',
      timestamp: '2025-06-13T09:20:00',
    },
    {
      id: 2,
      sender: 'user',
      text: "Yes! I'm trying to grow my small business online but don't know where to start.",
      timestamp: '2025-06-13T09:23:00',
    },
    {
      id: 3,
      sender: 'author',
      text: "I can definitely help with that! Let's start by discussing your target audience and goals.",
      timestamp: '2025-06-13T09:25:00',
    },
  ],
  5: [
    {
      id: 1,
      sender: 'author',
      text: 'Hello! Interested in data science?',
      timestamp: '2025-06-14T13:10:00',
    },
    {
      id: 2,
      sender: 'user',
      text: 'Hi David! Yes, I want to learn Python for data analysis.',
      timestamp: '2025-06-14T13:12:00',
    },
    {
      id: 3,
      sender: 'author',
      text: 'Great choice! Python is perfect for data analysis. Have you installed Python and any libraries yet?',
      timestamp: '2025-06-14T13:15:00',
    },
  ],
};

const formatTime = (timestamp) => {
  const date = new Date(timestamp);
  return date.toLocaleTimeString([], { hour: '2-digit', minute: '2-digit' });
};

export default function MessagesPage() {
  const { authorId } = useParams();
  const id = Number.parseInt(authorId);
  const author = authors.find((a) => a.id === id);

  const getInitialMessages = () => {
    const storedMessages = localStorage.getItem(`messages-${id}`);
    return storedMessages
      ? JSON.parse(storedMessages)
      : initialMessages[id] || [];
  };

  const [messages, setMessages] = useState(getInitialMessages);
  const [newMessage, setNewMessage] = useState('');
  const messagesEndRef = useRef(null);

  useEffect(() => {
    localStorage.setItem(`messages-${id}`, JSON.stringify(messages));
  }, [messages, id]);

  useEffect(() => {
    messagesEndRef.current?.scrollIntoView({ behavior: 'smooth' });
  }, [messages]);

  const handleSendMessage = (e) => {
    e.preventDefault();
    if (!newMessage.trim()) return;

    const message = {
      id: messages.length + 1,
      sender: 'user',
      text: newMessage,
      timestamp: new Date().toISOString(),
    };

    setMessages([...messages, message]);
    setNewMessage('');

    setTimeout(() => {
      const responses = [
        "That's a great question! Let me explain...",
        "I'd be happy to help you with that!",
        'Interesting point! Have you considered...',
        "I've worked on similar projects before. My approach would be...",
        "Let's schedule a skill swap session to discuss this in detail!",
      ];

      const responseMessage = {
        id: messages.length + 2,
        sender: 'author',
        text: responses[Math.floor(Math.random() * responses.length)],
        timestamp: new Date().toISOString(),
      };

      setMessages((prev) => [...prev, responseMessage]);
    }, 1000);
  };

  if (!author) {
    return <div className='container mx-auto py-8 px-4'>Author not found</div>;
  }

  return (
    <div className='container mx-auto py-8 md:py-12 lg:py-20 px-4 max-w-3xl'>
      <Card className='h-[calc(100vh-2rem)]'>
        <CardHeader className='border-b'>
          <div className='flex items-center'>
            <Link to='/authors' className='mr-4'>
              <Button variant='ghost' size='icon'>
                <ArrowLeft className='h-5 w-5' />
              </Button>
            </Link>
            <Avatar className='h-10 w-10 mr-3'>
              <AvatarImage src={author.avatar} alt={author.name} />
              <AvatarFallback>
                {author.name
                  .split(' ')
                  .map((n) => n[0])
                  .join('')}
              </AvatarFallback>
            </Avatar>
            <div>
              <CardTitle className='text-lg'>{author.name}</CardTitle>
              <div className='text-xs text-gray-500'>
                {author.skills.join(' • ')}
              </div>
            </div>
          </div>
        </CardHeader>
        <CardContent className='flex flex-col h-[calc(100%-8rem)]'>
          <div className='flex-grow overflow-y-auto py-4 space-y-4'>
            {messages.map((message) => (
              <div
                key={message.id}
                className={`flex ${
                  message.sender === 'user' ? 'justify-end' : 'justify-start'
                }`}
              >
                <div
                  className={`max-w-[80%] rounded-lg px-4 py-2 ${
                    message.sender === 'user'
                      ? 'bg-primary text-primary-foreground'
                      : 'bg-muted'
                  }`}
                >
                  <div>{message.text}</div>
                  <div
                    className={`text-xs mt-1 ${
                      message.sender === 'user'
                        ? 'text-primary-foreground/80'
                        : 'text-muted-foreground'
                    }`}
                  >
                    {formatTime(message.timestamp)}
                  </div>
                </div>
              </div>
            ))}
            <div ref={messagesEndRef} />
          </div>
          <form onSubmit={handleSendMessage} className='mt-4 flex gap-2'>
            <Input
              value={newMessage}
              onChange={(e) => setNewMessage(e.target.value)}
              placeholder='Type your message...'
              className='flex-grow'
            />
            <Button type='submit' size='icon'>
              <Send className='h-5 w-5' />
            </Button>
          </form>
        </CardContent>
      </Card>
    </div>
  );
}
