import { useState } from 'react';
import { Button } from '@/components/ui/button';
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import { Avatar, AvatarFallback, AvatarImage } from '@/components/ui/avatar';
import { Input } from '@/components/ui/input';
import { Textarea } from '@/components/ui/textarea';
import { Badge } from '@/components/ui/badge';
import { Label } from '@/components/ui/label';
import { Tabs, TabsContent, TabsList, TabsTrigger } from '@/components/ui/tabs';
import { PlusCircle, X, Save, Edit } from 'lucide-react';

const initialUserData = {
  name: 'Jamie Smith',
  bio: 'Passionate learner interested in photography, coding, and music. Always looking to expand my skills and connect with experts.',
  email: 'jamie.smith@example.com',
  location: 'San Francisco, CA',
  joinDate: 'June 2025',
  skills: ['JavaScript', 'Photography Basics', 'Content Writing'],
  learning: ['Advanced Photography', 'React Development', 'Piano'],
  connections: 12,
  skillSwaps: 8,
};

export default function ProfilePage() {
  const [userData, setUserData] = useState(initialUserData);
  const [isEditing, setIsEditing] = useState(false);
  const [editedData, setEditedData] = useState(userData);
  const [newSkill, setNewSkill] = useState('');
  const [newLearning, setNewLearning] = useState('');

  const handleSaveProfile = () => {
    setUserData(editedData);
    setIsEditing(false);
    localStorage.setItem('userData', JSON.stringify(editedData));
  };

  const handleAddSkill = () => {
    if (newSkill.trim() && !editedData.skills.includes(newSkill.trim())) {
      setEditedData({
        ...editedData,
        skills: [...editedData.skills, newSkill.trim()],
      });
      setNewSkill('');
    }
  };

  const handleRemoveSkill = (skillToRemove) => {
    setEditedData({
      ...editedData,
      skills: editedData.skills.filter((skill) => skill !== skillToRemove),
    });
  };

  const handleAddLearning = () => {
    if (
      newLearning.trim() &&
      !editedData.learning.includes(newLearning.trim())
    ) {
      setEditedData({
        ...editedData,
        learning: [...editedData.learning, newLearning.trim()],
      });
      setNewLearning('');
    }
  };

  const handleRemoveLearning = (learningToRemove) => {
    setEditedData({
      ...editedData,
      learning: editedData.learning.filter((item) => item !== learningToRemove),
    });
  };

  return (
    <div className='container mx-auto py-8 md:py-16 lg:py-24 px-4 max-w-4xl'>
      <Tabs defaultValue='profile' className='w-full'>
        <TabsList className='grid w-full grid-cols-2 mb-8'>
          <TabsTrigger value='profile'>Profile</TabsTrigger>
          <TabsTrigger value='activity'>Activity & Stats</TabsTrigger>
        </TabsList>

        <TabsContent value='profile'>
          <div className='grid grid-cols-1 md:grid-cols-3 gap-6'>
            {/* Profile Card */}
            <Card className='md:col-span-1'>
              <CardHeader className='text-center'>
                <div className='flex justify-center mb-4'>
                  <Avatar className='h-24 w-24'>
                    <AvatarImage src={userData.avatar} alt={userData.name} />
                    <AvatarFallback>
                      {userData.name
                        .split(' ')
                        .map((n) => n[0])
                        .join('')}
                    </AvatarFallback>
                  </Avatar>
                </div>
                <CardTitle>{userData.name}</CardTitle>
                <CardDescription>{userData.location}</CardDescription>
              </CardHeader>
              <CardContent className='space-y-4 text-center'>
                <div>
                  <p className='text-sm text-gray-500'>Member since</p>
                  <p>{userData.joinDate}</p>
                </div>
                <div className='flex justify-center space-x-6'>
                  <div>
                    <p className='text-sm text-gray-500'>Connections</p>
                    <p className='font-medium'>{userData.connections}</p>
                  </div>
                  <div>
                    <p className='text-sm text-gray-500'>Skill Swaps</p>
                    <p className='font-medium'>{userData.skillSwaps}</p>
                  </div>
                </div>
              </CardContent>
              <CardFooter>
                <Button
                  variant={isEditing ? 'outline' : 'default'}
                  className='w-full'
                  onClick={() =>
                    isEditing ? setIsEditing(false) : setIsEditing(true)
                  }
                >
                  {isEditing ? (
                    <>Cancel Editing</>
                  ) : (
                    <>
                      <Edit className='mr-2 h-4 w-4' />
                      Edit Profile
                    </>
                  )}
                </Button>
              </CardFooter>
            </Card>

            {/* Profile Details */}
            <Card className='md:col-span-2'>
              <CardHeader>
                <CardTitle>Profile Details</CardTitle>
                {isEditing && (
                  <Button onClick={handleSaveProfile} className='self-end'>
                    <Save className='mr-2 h-4 w-4' />
                    Save Changes
                  </Button>
                )}
              </CardHeader>
              <CardContent className='space-y-6'>
                {isEditing ? (
                  <>
                    <div className='space-y-2'>
                      <Label htmlFor='name'>Name</Label>
                      <Input
                        id='name'
                        value={editedData.name}
                        onChange={(e) =>
                          setEditedData({ ...editedData, name: e.target.value })
                        }
                      />
                    </div>
                    <div className='space-y-2'>
                      <Label htmlFor='email'>Email</Label>
                      <Input
                        id='email'
                        type='email'
                        value={editedData.email}
                        onChange={(e) =>
                          setEditedData({
                            ...editedData,
                            email: e.target.value,
                          })
                        }
                      />
                    </div>
                    <div className='space-y-2'>
                      <Label htmlFor='location'>Location</Label>
                      <Input
                        id='location'
                        value={editedData.location}
                        onChange={(e) =>
                          setEditedData({
                            ...editedData,
                            location: e.target.value,
                          })
                        }
                      />
                    </div>
                    <div className='space-y-2'>
                      <Label htmlFor='bio'>Bio</Label>
                      <Textarea
                        id='bio'
                        rows={4}
                        value={editedData.bio}
                        onChange={(e) =>
                          setEditedData({ ...editedData, bio: e.target.value })
                        }
                      />
                    </div>

                    {/* Skills section */}
                    <div className='space-y-2'>
                      <Label>Skills I Can Teach</Label>
                      <div className='flex flex-wrap gap-2 mb-2'>
                        {editedData.skills.map((skill) => (
                          <Badge
                            key={skill}
                            variant='secondary'
                            className='pl-2 pr-1 py-1 flex items-center gap-1'
                          >
                            {skill}
                            <button
                              onClick={() => handleRemoveSkill(skill)}
                              className='ml-1 rounded-full hover:bg-gray-200 p-0.5'
                            >
                              <X className='h-3 w-3' />
                            </button>
                          </Badge>
                        ))}
                      </div>
                      <div className='flex gap-2'>
                        <Input
                          placeholder='Add a skill...'
                          value={newSkill}
                          onChange={(e) => setNewSkill(e.target.value)}
                          onKeyDown={(e) =>
                            e.key === 'Enter' && handleAddSkill()
                          }
                        />
                        <Button
                          variant='outline'
                          size='icon'
                          onClick={handleAddSkill}
                        >
                          <PlusCircle className='h-4 w-4' />
                        </Button>
                      </div>
                    </div>

                    {/* Learning section */}
                    <div className='space-y-2'>
                      <Label>Skills I Want to Learn</Label>
                      <div className='flex flex-wrap gap-2 mb-2'>
                        {editedData.learning.map((item) => (
                          <Badge
                            key={item}
                            variant='outline'
                            className='pl-2 pr-1 py-1 flex items-center gap-1'
                          >
                            {item}
                            <button
                              onClick={() => handleRemoveLearning(item)}
                              className='ml-1 rounded-full hover:bg-gray-200 p-0.5'
                            >
                              <X className='h-3 w-3' />
                            </button>
                          </Badge>
                        ))}
                      </div>
                      <div className='flex gap-2'>
                        <Input
                          placeholder='Add a learning goal...'
                          value={newLearning}
                          onChange={(e) => setNewLearning(e.target.value)}
                          onKeyDown={(e) =>
                            e.key === 'Enter' && handleAddLearning()
                          }
                        />
                        <Button
                          variant='outline'
                          size='icon'
                          onClick={handleAddLearning}
                        >
                          <PlusCircle className='h-4 w-4' />
                        </Button>
                      </div>
                    </div>
                  </>
                ) : (
                  <>
                    <div>
                      <h3 className='text-sm font-medium text-gray-500'>
                        Email
                      </h3>
                      <p>{userData.email}</p>
                    </div>
                    <div>
                      <h3 className='text-sm font-medium text-gray-500'>Bio</h3>
                      <p>{userData.bio}</p>
                    </div>
                    <div>
                      <h3 className='text-sm font-medium text-gray-500'>
                        Skills I Can Teach
                      </h3>
                      <div className='flex flex-wrap gap-2 mt-2'>
                        {userData.skills.map((skill) => (
                          <Badge key={skill} variant='secondary'>
                            {skill}
                          </Badge>
                        ))}
                      </div>
                    </div>
                    <div>
                      <h3 className='text-sm font-medium text-gray-500'>
                        Skills I Want to Learn
                      </h3>
                      <div className='flex flex-wrap gap-2 mt-2'>
                        {userData.learning.map((item) => (
                          <Badge key={item} variant='outline'>
                            {item}
                          </Badge>
                        ))}
                      </div>
                    </div>
                  </>
                )}
              </CardContent>
            </Card>
          </div>
        </TabsContent>

        <TabsContent value='activity'>
          <Card>
            <CardHeader>
              <CardTitle>Activity & Statistics</CardTitle>
              <CardDescription>
                Track your progress and engagement on SkillSwap
              </CardDescription>
            </CardHeader>
            <CardContent>
              <div className='space-y-8'>
                <div>
                  <h3 className='text-lg font-medium mb-4'>
                    Recent Skill Swaps
                  </h3>
                  <div className='space-y-4'>
                    {[
                      {
                        name: 'Alex Johnson',
                        skill: 'Photography Basics',
                        date: 'June 15, 2025',
                      },
                      {
                        name: 'Maya Patel',
                        skill: 'React Development',
                        date: 'May 28, 2025',
                      },
                      {
                        name: 'Carlos Rodriguez',
                        skill: 'Music Theory',
                        date: 'May 10, 2025',
                      },
                    ].map((swap, index) => (
                      <div
                        key={index}
                        className='flex items-center justify-between border-b pb-3'
                      >
                        <div className='flex items-center gap-3'>
                          <Avatar className='h-10 w-10'>
                            <AvatarFallback>
                              {swap.name
                                .split(' ')
                                .map((n) => n[0])
                                .join('')}
                            </AvatarFallback>
                          </Avatar>
                          <div>
                            <p className='font-medium'>{swap.name}</p>
                            <p className='text-sm text-gray-500'>
                              {swap.skill}
                            </p>
                          </div>
                        </div>
                        <span className='text-sm text-gray-500'>
                          {swap.date}
                        </span>
                      </div>
                    ))}
                  </div>
                </div>

                <div>
                  <h3 className='text-lg font-medium mb-4'>
                    Learning Progress
                  </h3>
                  <div className='grid grid-cols-1 md:grid-cols-3 gap-4'>
                    {userData.learning.map((skill, index) => (
                      <Card key={index}>
                        <CardHeader className='pb-2'>
                          <CardTitle className='text-base'>{skill}</CardTitle>
                        </CardHeader>

                        <CardContent>
                          <div className='space-y-2'>
                            <div className='flex justify-between text-sm'>
                              <span>Progress</span>
                              <span>{[30, 45, 15][index % 3]}%</span>
                            </div>
                            <div className='w-full bg-gray-200 rounded-full h-2.5'>
                              <div
                                className='bg-primary h-2.5 rounded-full'
                                style={{ width: `${[30, 45, 15][index % 3]}%` }}
                              ></div>
                            </div>
                          </div>
                        </CardContent>
                      </Card>
                    ))}
                  </div>
                </div>
              </div>
            </CardContent>
          </Card>
        </TabsContent>
      </Tabs>
    </div>
  );
}
